@@ -168,6 +168,8 @@ class LibvirtCheck(AgentCheck):
         for inst in insp._get_connection().listAllDomains():
             # Verify that this instance exists in the cache.  Add if necessary.
             inst_name = inst.name()
+            if inst_name not in instance_cache:
+                instance_cache = self._update_instance_cache()
 
             # Build customer dimensions
             try:
@@ -196,15 +198,13 @@ class LibvirtCheck(AgentCheck):
                 self.gauge('vm.host_alive_status', 2, dimensions=dims_operations,
                            value_meta={'detail': detail})
                 continue
-            if inst_name not in instance_cache:
-                instance_cache = self._update_instance_cache()
             if inst_name not in metric_cache:
                 metric_cache[inst_name] = {}
 
             # Skip instances created within the probation period
             vm_probation_remaining = self._test_vm_probation(instance_cache.get(inst_name)['created'])
             if (vm_probation_remaining >= 0):
-                self.log.info("Libvirt: {0} in probation for another {1} seconds".format(instance_cache.get(inst_name)['hostname'],
+                self.log.info("Libvirt: {0} in probation for another {1} seconds".format(instance_cache.get(inst_name)['hostname'].encode('utf8'),
                                                                                          vm_probation_remaining))
                 continue
 
@@ -288,11 +288,23 @@ class LibvirtCheck(AgentCheck):
                         'timestamp': sample_time,
                         'value': value}
 
-            # Disk utilization
-            # TODO(dschroeder)
-
             # Memory utilizaion
-            # TODO(dschroeder)
+            # (req. balloon driver; Linux kernel param CONFIG_VIRTIO_BALLOON)
+            try:
+                mem_metrics = {'mem.free_mb': float(inst.memoryStats()['unused']) / 1024,
+                               'mem.swap_used_mb': float(inst.memoryStats()['swap_out']) / 1024,
+                               'mem.total_mb': float(inst.memoryStats()['available'] - inst.memoryStats()['unused']) / 1024,
+                               'mem.used_mb': float(inst.memoryStats()['available'] - inst.memoryStats()['unused']) / 1024,
+                               'mem.free_perc': float(inst.memoryStats()['unused']) / float(inst.memoryStats()['available']) * 100}
+                for name in mem_metrics:
+                    self.gauge(name, mem_metrics[name], dimensions=dims_customer,
+                               delegated_tenant=instance_cache.get(inst_name)['tenant_id'],
+                               hostname=instance_cache.get(inst_name)['hostname'])
+                    self.gauge("vm.{0}".format(name), mem_metrics[name],
+                               dimensions=dims_operations)
+            except KeyError:
+                self.log.debug("Balloon driver not active/available on guest {0} ({1})".format(inst_name,
+                                                                                               instance_cache.get(inst_name)['hostname']))
 
             # Network activity
             for vnic in insp.inspect_vnics(inst):
