@@ -1,20 +1,21 @@
-"""Classes implementing different methods for running monasca-agent on startup as well as starting the process immediately.
+"""Code to handle various service managers used on different OS
 
 """
 import psutil
 
 
 class Service(object):
-
     """Abstract base class implementing the interface for various service types.
 
     """
 
-    def __init__(self, prefix_dir, config_dir, log_dir, name='monasca-agent'):
+    def __init__(self, prefix_dir, config_dir, log_dir, template_dir, name='monasca-agent', username='monasca-agent'):
         self.prefix_dir = prefix_dir
         self.config_dir = config_dir
         self.log_dir = log_dir
+        self.template_dir = template_dir
         self.name = name
+        self.username = username
 
     def enable(self):
         """Sets monasca-agent to start on boot.
@@ -42,14 +43,13 @@ class Service(object):
         """
         raise NotImplementedError
 
-    @staticmethod
-    def is_running():
+    def is_running(self):
         """Returns True if monasca-agent is running, false otherwise.
 
         """
         # Looking for the supervisor process not the individual components
         for process in psutil.process_iter():
-            if '/etc/monasca/agent/supervisor.conf' in process.cmdline():
+            if '{0}/supervisor.conf'.format(self.config_dir) in process.cmdline():
                 return True
 
         return False
